==> j2sdk-1_4_2_03-i586-1.tgz: com/sun/java/swing/plaf/gtk/resources/gtk_it.java <==
package com.sun.java.swing.plaf.gtk.resources;

import java.util.ListResourceBundle;

public final class gtk_it extends ListResourceBundle {
    private static final Object[][] contents = {
        { "FileChooser.acceptAllFileFilterText", "*" },
        { "FileChooser.cancelButtonText", "Annulla" },
        { "FileChooser.cancelButtonToolTipText", "Chiude la finestra di dialogo di selezione colore." },
        { "FileChooser.deleteFileButtonText", "Elimina file" },
        { "FileChooser.filesLabelText", "File" },
        { "FileChooser.foldersLabelText", "Cartelle" },
        { "FileChooser.newFolderButtonText", "Nuova cartella" },
        { "FileChooser.openButtonText", "OK" },
        { "FileChooser.openButtonToolTipText", "Apre il file selezionato." },
        { "FileChooser.openDialogTitleText", "Apri" },
        { "FileChooser.pathLabelText", "Selezione:" },
        { "FileChooser.renameFileButtonText", "Rinomina file" },
        { "FileChooser.saveButtonText", "Salva" },
        { "FileChooser.saveButtonToolTipText", "Salva il file selezionato." },
        { "FileChooser.saveDialogTitleText", "Salva" },
        { "GTKColorChooserPanel.blueMnemonic", "66" },
        { "GTKColorChooserPanel.blueText", "Blu:" },
        { "GTKColorChooserPanel.colorNameMnemonic", "78" },
        { "GTKColorChooserPanel.colorNameText", "Nome colore:" },
        { "GTKColorChooserPanel.greenMnemonic", "69" },
        { "GTKColorChooserPanel.greenText", "Verde:" },
        { "GTKColorChooserPanel.hueMnemonic", "84" },
        { "GTKColorChooserPanel.hueText", "Tonalit\u00E0:" },
        { "GTKColorChooserPanel.mnemonic", "71" },
        { "GTKColorChooserPanel.nameText", "Selezione colore GTK" },
        { "GTKColorChooserPanel.redMnemonic", "82" },
        { "GTKColorChooserPanel.redText", "Rosso:" },
        { "GTKColorChooserPanel.saturationMnemonic", "83" },
        { "GTKColorChooserPanel.saturationText", "Saturazione:" },
        { "GTKColorChooserPanel.valueMnemonic", "86" },
        { "GTKColorChooserPanel.valueText", "Valore:" },

    };

    protected final Object[][] getContents() {
         return contents;
    }
}

==> j2sdk-1_5_0_01-i586-1.tgz: com/sun/java/swing/plaf/gtk/resources/gtk_it.java <==
package com.sun.java.swing.plaf.gtk.resources;

import java.util.ListResourceBundle;

public final class gtk_it extends ListResourceBundle {
    private static final Object[][] contents = {
        { "FileChooser.acceptAllFileFilterText", "Tutti i file" },
        { "FileChooser.cancelButtonText", "Annulla" },
        { "FileChooser.cancelButtonToolTipText", "Chiude la finestra di dialogo di selezione colore." },
        { "FileChooser.deleteFileButtonText", "Elimina file" },
        { "FileChooser.filesLabelText", "File" },
        { "FileChooser.filterLabelText", "Filtro:" },
        { "FileChooser.foldersLabelText", "Cartelle" },
        { "FileChooser.newFolderButtonText", "Nuova cartella" },
        { "FileChooser.newFolderDialogText", "Nome della cartella:" },
        { "FileChooser.openButtonText", "OK" },
        { "FileChooser.openButtonToolTipText", "Apre il file selezionato." },
        { "FileChooser.openDialogTitleText", "Apri" },
        { "FileChooser.pathLabelText", "Selezione:" },
        { "FileChooser.renameFileButtonText", "Rinomina file" },
        { "FileChooser.renameFileDialogText", "Rinomina del file \"{0}\" in" },
        { "FileChooser.renameFileErrorText", "Errore nella rinomina del file \"{0}\" in \"{1}\"" },
        { "FileChooser.renameFileErrorTitle", "Errore" },
        { "FileChooser.saveButtonText", "Salva" },
        { "FileChooser.saveButtonToolTipText", "Salva il file selezionato." },
        { "FileChooser.saveDialogTitleText", "Salva" },
        { "GTKColorChooserPanel.blueMnemonic", "66" },
        { "GTKColorChooserPanel.blueText", "Blu:" },
        { "GTKColorChooserPanel.colorNameMnemonic", "78" },
        { "GTKColorChooserPanel.colorNameText", "Nome colore:" },
        { "GTKColorChooserPanel.greenMnemonic", "69" },
        { "GTKColorChooserPanel.greenText", "Verde:" },
        { "GTKColorChooserPanel.hueMnemonic", "84" },
        { "GTKColorChooserPanel.hueText", "Tonalit\u00E0:" },
        { "GTKColorChooserPanel.mnemonic", "71" },
        { "GTKColorChooserPanel.nameText", "Selezione colore GTK" },
        { "GTKColorChooserPanel.redMnemonic", "82" },
        { "GTKColorChooserPanel.redText", "Rosso:" },
        { "GTKColorChooserPanel.saturationMnemonic", "83" },
        { "GTKColorChooserPanel.saturationText", "Saturazione:" },
        { "GTKColorChooserPanel.valueMnemonic", "86" },
        { "GTKColorChooserPanel.valueText", "Valore:" },

    };

    protected final Object[][] getContents() {
         return contents;
    }
}
